
This is a simple TK nonlinear sliding package.You can use
```python
move(currently_x,currently_y,to_x,to_y,n,win,debug = False,sleep = 0.01,wait_on_startup = True)
```
make a call

Parameter Introduction
move(
currently_x  The x-coordinate of the current component
currently_y  The y-coordinate of the current component
to_x  Move to x coordinate
to_y  Move to y coordinate
n  component
win  window
debug=False  debug
sleep=0.01  Sliding waiting
wait_on_startup=True  Wait for 0.5 seconds at startup
)
